@@ -13,7 +13,7 @@ package Printer::ESCPOS::Profiles::Generic;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '1.003'; # VERSION
+our $VERSION = '1.004'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -773,7 +773,7 @@ Printer::ESCPOS::Profiles::Generic - Generic Profile for Printers for L<Printer:
 
 =head1 VERSION
 
-version 1.003
+version 1.004
 
 =head1 METHODS
 
@@ -859,7 +859,7 @@ This method uses native fonts to print utf8 compatible characters including inte
 is slower than direct text printing but it allows exceptional styling options allowing you to print text using system
 fonts in a wide range of font sizes and styles with many more choices than what a thermal printer otherwise provides.
 
-In the background this function uses [Pango] and [Cairo] libraries to create a one line image from a given font styles,
+In the background this function uses L<Pango> and L<Cairo> libraries to create a one line image from a given font styles,
 font family in a given font size. Note that you must not use this method to print more than a single line at a time.
 When you want to print the next line call this method again to print to the next line.
 
